@@ -851,6 +851,53 @@ int32_t SPVM__Net__SSLeay__get0_alpn_selected(SPVM_ENV* env, SPVM_VALUE* stack)
   return 0;
 }
 
+int32_t SPVM__Net__SSLeay__select_next_proto(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int32_t error_id = 0;
+  
+  void* obj_out_ref = stack[0].oval;
+  
+  int8_t* outlen_ref = stack[1].bref;
+  
+  void* obj_server = stack[2].oval;
+  
+  int32_t server_len = stack[3].ival;
+  
+  void* obj_client = stack[4].oval;
+  
+  int32_t client_len = stack[5].ival;
+  
+  if (!(obj_out_ref && env->length(env, stack, obj_out_ref) == 1)) {
+    return env->die(env, stack, "The output reference $out_ref must be 1-length array.", __func__, FILE_NAME, __LINE__);
+  }
+  
+  if (!obj_server) {
+    return env->die(env, stack, "$server must be defined.", __func__, FILE_NAME, __LINE__);
+  }
+  
+  const char* server = env->get_chars(env, stack, obj_server);
+  
+  if (!obj_client) {
+    return env->die(env, stack, "$client must be defined.", __func__, FILE_NAME, __LINE__);
+  }
+  
+  const char* client = env->get_chars(env, stack, obj_client);
+  
+  unsigned char* out_tmp = NULL;
+  
+  int32_t status = SSL_select_next_proto(&out_tmp, (unsigned char*)outlen_ref, server, server_len, client, client_len);
+  
+  if (out_tmp) {
+    void* obj_data = env->new_string(env, stack, out_tmp, *outlen_ref);
+    
+    env->set_elem_object(env, stack, obj_out_ref, 0, obj_data);
+  }
+  
+  stack[0].ival = status;
+  
+  return 0;
+}
+
 static void SPVM__Net__SSLeay__my__msg_callback(int write_p, int version, int content_type, const void* buf, size_t len, SSL* ssl, void* native_arg) {
   
   int32_t error_id = 0;
@@ -881,13 +928,6 @@ static void SPVM__Net__SSLeay__my__msg_callback(int write_p, int version, int co
     goto END_OF_FUNC;
   }
   
-  void* obj_arg = env->get_field_object_by_name(env, stack, obj_self, "msg_callback_arg", &error_id, __func__, FILE_NAME, __LINE__);
-  if (error_id) {
-    env->print_exception_to_stderr(env, stack);
-    
-    goto END_OF_FUNC;
-  }
-  
   void* obj_buf = env->new_string(env, stack, buf, len);
   
   stack[0].oval = obj_cb;
@@ -897,7 +937,6 @@ static void SPVM__Net__SSLeay__my__msg_callback(int write_p, int version, int co
   stack[4].oval = obj_buf;
   stack[5].ival = len;
   stack[6].oval = obj_self;
-  stack[7].oval = obj_arg;
   env->call_instance_method_by_name(env, stack, "", 7, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) {
     env->print_exception_to_stderr(env, stack);
@@ -923,8 +962,6 @@ int32_t SPVM__Net__SSLeay__set_msg_callback(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_cb = stack[1].oval;
   
-  void* obj_arg = stack[2].oval;
-  
   SSL* self = env->get_pointer(env, stack, obj_self);
   
   void (*native_cb)(int write_p, int version, int content_type, const void *buf, size_t len, SSL *ssl, void *arg) = NULL;
@@ -938,9 +975,6 @@ int32_t SPVM__Net__SSLeay__set_msg_callback(SPVM_ENV* env, SPVM_VALUE* stack) {
     if (error_id) { return error_id; }
   }
   
-  env->set_field_object_by_name(env, stack, obj_self, "msg_callback_arg", obj_arg, &error_id, __func__, FILE_NAME, __LINE__);
-  if (error_id) { return error_id; }
-  
   return 0;
 }
 
